@@ -1,4 +1,3 @@
-# coding: utf-8
 """test the IPython Kernel"""
 
 # Copyright (c) IPython Development Team.
@@ -17,7 +16,6 @@ from packaging import version
 
 from IPython.testing import decorators as dec, tools as tt
 import IPython
-from ipython_genutils import py3compat
 from IPython.paths import locate_profile
 from ipython_genutils.tempdir import TemporaryDirectory
 
@@ -80,7 +78,10 @@ def test_sys_path_profile_dir():
 
 
 @flaky(max_runs=3)
-@dec.skipif(sys.platform == 'win32', "subprocess prints fail on Windows")
+@dec.skipif(
+    sys.platform == 'win32' or (sys.platform == "darwin" and sys.version_info >=(3, 8)),
+    "subprocess prints fail on Windows and MacOS Python 3.8+"
+)
 def test_subprocess_print():
     """printing from forked mp.Process"""
     with new_kernel() as kc:
@@ -90,7 +91,6 @@ def test_subprocess_print():
         flush_channels(kc)
         np = 5
         code = '\n'.join([
-            "from __future__ import print_function",
             "import time",
             "import multiprocessing as mp",
             "pool = [mp.Process(target=print, args=('hello', i,)) for i in range(%i)]" % np,
@@ -133,7 +133,10 @@ def test_subprocess_noprint():
 
 
 @flaky(max_runs=3)
-@dec.skipif(sys.platform == 'win32', "subprocess prints fail on Windows")
+@dec.skipif(
+    sys.platform == 'win32' or (sys.platform == "darwin" and sys.version_info >=(3, 8)),
+    "subprocess prints fail on Windows and MacOS Python 3.8+"
+)
 def test_subprocess_error():
     """error in mp.Process doesn't crash"""
     with new_kernel() as kc:
@@ -157,16 +160,16 @@ def test_subprocess_error():
 # raw_input tests
 
 def test_raw_input():
-    """test [raw_]input"""
+    """test input"""
     with kernel() as kc:
         iopub = kc.iopub_channel
 
-        input_f = "input" if py3compat.PY3 else "raw_input"
+        input_f = "input"
         theprompt = "prompt> "
         code = 'print({input_f}("{theprompt}"))'.format(**locals())
         msg_id = kc.execute(code, allow_stdin=True)
         msg = kc.get_stdin_msg(block=True, timeout=TIMEOUT)
-        assert msg['header']['msg_type'] == u'input_request'
+        assert msg['header']['msg_type'] == 'input_request'
         content = msg['content']
         assert content['prompt'] == theprompt
         text = "some text"
@@ -177,49 +180,28 @@ def test_raw_input():
         assert stdout == text + "\n"
 
 
-@dec.skipif(py3compat.PY3)
-def test_eval_input():
-    """test input() on Python 2"""
-    with kernel() as kc:
-        iopub = kc.iopub_channel
-
-        input_f = "input" if py3compat.PY3 else "raw_input"
-        theprompt = "prompt> "
-        code = 'print(input("{theprompt}"))'.format(**locals())
-        msg_id = kc.execute(code, allow_stdin=True)
-        msg = kc.get_stdin_msg(block=True, timeout=TIMEOUT)
-        assert msg['header']['msg_type'] == u'input_request'
-        content = msg['content']
-        assert content['prompt'] == theprompt
-        kc.input("1+1")
-        reply = kc.get_shell_msg(block=True, timeout=TIMEOUT)
-        assert reply['content']['status'] == 'ok'
-        stdout, stderr = assemble_output(iopub)
-        assert stdout == "2\n"
-
-
 def test_save_history():
     # Saving history from the kernel with %hist -f was failing because of
     # unicode problems on Python 2.
     with kernel() as kc, TemporaryDirectory() as td:
         file = os.path.join(td, 'hist.out')
-        execute(u'a=1', kc=kc)
+        execute('a=1', kc=kc)
         wait_for_idle(kc)
-        execute(u'b=u"abcþ"', kc=kc)
+        execute('b="abcþ"', kc=kc)
         wait_for_idle(kc)
         _, reply = execute("%hist -f " + file, kc=kc)
         assert reply['status'] == 'ok'
         with io.open(file, encoding='utf-8') as f:
             content = f.read()
-        assert u'a=1' in content
-        assert u'b=u"abcþ"' in content
+        assert 'a=1' in content
+        assert 'b="abcþ"' in content
 
 
 @dec.skip_without('faulthandler')
 def test_smoke_faulthandler():
     with kernel() as kc:
         # Note: faulthandler.register is not available on windows.
-        code = u'\n'.join([
+        code = '\n'.join([
             'import sys',
             'import faulthandler',
             'import signal',
@@ -262,7 +244,7 @@ def test_is_complete():
 @dec.skipif(sys.platform != 'win32', "only run on Windows")
 def test_complete():
     with kernel() as kc:
-        execute(u'a = 1', kc=kc)
+        execute('a = 1', kc=kc)
         wait_for_idle(kc)
         cell = 'import IPython\nb = a.'
         kc.complete(cell)
@@ -321,7 +303,7 @@ def test_message_order():
             assert reply['parent_header']['msg_id'] == msg_id
 
 
-@dec.skipif(sys.platform.startswith('linux'))
+@dec.skipif(sys.platform.startswith('linux') or sys.platform.startswith('darwin'))
 def test_unc_paths():
     with kernel() as kc, TemporaryDirectory() as td:
         drive_file_path = os.path.join(td, 'unc.txt')
@@ -355,7 +337,7 @@ def test_shutdown():
     """Kernel exits after polite shutdown_request"""
     with new_kernel() as kc:
         km = kc.parent
-        execute(u'a = 1', kc=kc)
+        execute('a = 1', kc=kc)
         wait_for_idle(kc)
         kc.shutdown()
         for i in range(300): # 30s timeout
@@ -369,7 +351,7 @@ def test_shutdown():
 def test_interrupt_during_input():
     """
     The kernel exits after being interrupted while waiting in input().
-    
+
     input() appears to have issues other functions don't, and it needs to be
     interruptible in order for pdb to be interruptible.
     """
@@ -408,4 +390,4 @@ def test_interrupt_during_pdb_set_trace():
         reply = kc.get_shell_msg(timeout=TIMEOUT)
         validate_message(reply, 'execute_reply', msg_id)
         reply = kc.get_shell_msg(timeout=TIMEOUT)
-        validate_message(reply, 'execute_reply', msg_id2)
\ No newline at end of file
+        validate_message(reply, 'execute_reply', msg_id2)
